OH_ImageSourceNative_ModifyImageProperty

Function OH_ImageSourceNative_ModifyImageProperty 

pub unsafe extern "C" fn OH_ImageSourceNative_ModifyImageProperty(
    source: *mut OH_ImageSourceNative,
    key: *mut Image_String,
    value: *mut Image_String,
) -> ImageResult
Available on crate features api-12 and image-source only.
Modifies the value of an image property of an ImageSource object.

Arguments

  • source - Indicates a void pointer(from ImageSource pointer convert).

  • key - Indicates a pointer to the property. For details, see Image_String., key is an exif constant. Release after use ImageSource, see OH_ImageSourceNative_Release.

  • value - Indicates a pointer to the new value of the property.

Returns

  • Returns [Image_ErrorCode]

Available since API-level: 12