OH_PixelmapNative_AccessPixels

Function OH_PixelmapNative_AccessPixels 

pub unsafe extern "C" fn OH_PixelmapNative_AccessPixels(
    pixelmap: *mut OH_PixelmapNative,
    addr: *mut *mut c_void,
) -> ImageResult
Available on crate features api-12 and pixelmap and api-15 only.
Obtains the memory address of a PixelMap and locks the memory. When the memory is locked, any operation that modifies or releases the PixelMap will fail and return [IMAGE_BAD_PARAMETER].

Arguments

  • pixelmap - The PixelMap pointer to be operated.

  • addr - The double pointer to the memory address of the PixelMap.

Returns

  • Function result code: [IMAGE_SUCCESS] If the operation is successful. [IMAGE_BAD_PARAMETER] If invalid parameter, pixelmap or addr are invalid. [IMAGE_LOCK_UNLOCK_FAILED] If memory failed to be locked. OH_PixelmapNative Available since API-level: 15