pub unsafe extern "C" fn OH_DecodingOptions_GetCropAndScaleStrategy(
options: *mut OH_DecodingOptions,
cropAndScaleStrategy: *mut i32,
) -> ImageResultAvailable on crate features
api-12 and image-source and api-18 only.Expand description
Obtains the cropping and scaling strategy of decoding options.
Arguments
-
options- Pointer to the decoding options. -
cropAndScaleStrategy- Pointer to the strategy for executing the cropping and scaling operations when both desiredSize and desiredRegion are specified.
Returns
- Returns one of the following result codes:
[
IMAGE_SUCCESS]: The execution is successful. [IMAGE_BAD_PARAMETER]: options or cropAndScaleStrategy is a null pointer.
Available since API-level: 18