pub unsafe extern "C" fn OH_ImageSourceNative_CreatePixelmap(
source: *mut OH_ImageSourceNative,
options: *mut OH_DecodingOptions,
pixelmap: *mut *mut OH_PixelmapNative,
) -> ImageResultAvailable on crate features
api-12 and image-source only.Expand description
Decodes an void pointer
based on the specified OH_DecodingOptions struct.
Arguments
-
source- Indicates a void pointer(from ImageSource pointer convert). -
options- Indicates a pointer to the options for decoding the image source. For details, seeOH_DecodingOptions. -
pixelmap- Indicates a void pointer to the Pixelmap object obtained at the C++ native layer.
Returns
- Returns [
Image_ErrorCode]
Available since API-level: 12